#[non_exhaustive]pub enum SymmetricEigenError {
Failed,
}Expand description
Reasons a SymmetricEigen::try_eigh call can fail. Variants
are backend-agnostic — backends translate their native error types
into these.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Failed
The eigensolver iteration failed to converge to the requested accuracy. Both backends use bounded-iteration QR / divide-and- conquer methods that can in principle fail on pathological inputs.